==> armadillo-0.1.0.zip: src/jp/sourceforge/armadillo/ArchiveEntry.java <==
package jp.sourceforge.armadillo;

/**
 * A[JCõGgB
 * ̃Gg̎QƂ͕ێȂB
 */
public final class ArchiveEntry {

    /**
     * <code>NULL</code>GgB
     * eEntry<code>null</code>ɑΉB
     */
    public static final ArchiveEntry NULL = new ArchiveEntry("");

    private String name;
    private String method;
    private long lastModified;
    private long crc;
    private long compressedSize;
    private long size;

    /**
     * ArchiveEntry̐B
     * @param name Gg
     */
    public ArchiveEntry(String name) {
        this.name = name;
        this.method = "";
        this.lastModified = Long.MIN_VALUE;
        this.crc = Long.MIN_VALUE;
        this.size = Long.MIN_VALUE;
        this.compressedSize = Long.MIN_VALUE;
    }

    /**
     * <code>null</code>Ggł(GgȏȂ)ǂԂB
     * @return <code>null</code>GgȂ <code>true</code>AłȂ <code>false</code>
     */
    public boolean isNull() {
        return this == NULL;
    }

    /**
     * name̎擾B
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * name̐ݒB
     * @param name name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * directory̎擾B
     * @return directory
     */
    public boolean isDirectory() {
        return name.endsWith("/");
    }

    /**
     * method̎擾B
     * @return method
     */
    public String getMethod() {
        return method;
    }

    /**
     * method̐ݒB
     * @param method method
     */
    public void setMethod(String method) {
        this.method = method;
    }

    /**
     * lastModified̎擾B
     * @return lastModified
     */
    public long getLastModified() {
        return lastModified;
    }

    /**
     * lastModified̐ݒB
     * @param lastModified lastModified
     */
    public void setLastModified(long lastModified) {
        this.lastModified = lastModified;
    }

    /**
     * size̎擾B
     * @return size
     */
    public long getSize() {
        return size;
    }

    /**
     * size̐ݒB
     * @param size size
     */
    public void setSize(long size) {
        this.size = size;
    }

    /**
     * compressedSize̎擾B
     * @return compressedSize
     */
    public long getCompressedSize() {
        return compressedSize;
    }

    /**
     * compressedSize̐ݒB
     * @param compressedSize compressedSize
     */
    public void setCompressedSize(long compressedSize) {
        this.compressedSize = compressedSize;
    }

    /**
     * crc̎擾B
     * @return crc
     */
    public long getCrc() {
        return crc;
    }

    /**
     * crc̐ݒB
     * @param crc crc
     */
    public void setCrc(long crc) {
        this.crc = crc;
    }

    /* (overridden)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return "ArchiveEntry:" + name;
    }

}

==> armadillo-0.1.3.zip: src/jp/sourceforge/armadillo/ArchiveEntry.java <==
package jp.sourceforge.armadillo;

/**
 * A[JCõGgB
 * ̃Gg̎QƂ͕ێȂB
 */
public final class ArchiveEntry {

    /**
     * <code>NULL</code>GgB
     * eEntry<code>null</code>ɑΉB
     */
    public static final ArchiveEntry NULL = new ArchiveEntry("");

    private boolean added;
    private String name;
    private String method;
    private long lastModified;
    private long crc;
    private long compressedSize;
    private long size;

    /**
     * ArchiveEntry̐B
     * @param name Gg
     */
    public ArchiveEntry(String name) {
        this.name = name;
        this.method = "";
        this.lastModified = Long.MIN_VALUE;
        this.crc = Long.MIN_VALUE;
        this.size = Long.MIN_VALUE;
        this.compressedSize = Long.MIN_VALUE;
    }

    /**
     * <code>null</code>Ggł(GgȏȂ)ǂԂB
     * @return <code>null</code>GgȂ <code>true</code>AłȂ <code>false</code>
     */
    public boolean isNull() {
        return this == NULL;
    }

    /**
     * GgǉꂽǂԂB
     * @return added Ggǉꂽꍇ <code>true</code>AłȂ <code>false</code>
     */
    public boolean isAdded() {
        return added;
    }

    /**
     * Ggǉꂽǂݒ肷B
     * @param added Ggǉꂽꍇ <code>true</code>AłȂ <code>false</code>
     */
    public void setAdded(boolean added) {
        this.added = added;
    }

    /**
     * name̎擾B
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * name̐ݒB
     * @param name name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * directory̎擾B
     * @return directory
     */
    public boolean isDirectory() {
        return name.endsWith("/");
    }

    /**
     * method̎擾B
     * @return method
     */
    public String getMethod() {
        return method;
    }

    /**
     * method̐ݒB
     * @param method method
     */
    public void setMethod(String method) {
        this.method = method;
    }

    /**
     * lastModified̎擾B
     * @return lastModified
     */
    public long getLastModified() {
        return lastModified;
    }

    /**
     * lastModified̐ݒB
     * @param lastModified lastModified
     */
    public void setLastModified(long lastModified) {
        this.lastModified = lastModified;
    }

    /**
     * size̎擾B
     * @return size
     */
    public long getSize() {
        return size;
    }

    /**
     * size̐ݒB
     * @param size size
     */
    public void setSize(long size) {
        this.size = size;
    }

    /**
     * compressedSize̎擾B
     * @return compressedSize
     */
    public long getCompressedSize() {
        return compressedSize;
    }

    /**
     * compressedSize̐ݒB
     * @param compressedSize compressedSize
     */
    public void setCompressedSize(long compressedSize) {
        this.compressedSize = compressedSize;
    }

    /**
     * crc̎擾B
     * @return crc
     */
    public long getCrc() {
        return crc;
    }

    /**
     * crc̐ݒB
     * @param crc crc
     */
    public void setCrc(long crc) {
        this.crc = crc;
    }

    /* (overridden)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return "ArchiveEntry:" + name;
    }

}
